; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10

;-| AI Activation Commands |-----------------------------------------------
; From BBH
[Command]
name = "CPU0"
command = U,U,D,D,B,F,B,F,s,s
time = 0

[Command]
name = "CPU1"
command = U,U,D,D,B,F,B,F,a,a
time = 0

[Command]
name = "CPU2"
command = U,U,D,D,B,F,B,F,b,b
time = 0

[Command]
name = "CPU3"
command = U,U,D,D,B,F,B,F,c,c
time = 0

[Command]
name = "CPU4"
command = U,U,D,D,B,F,B,F,x,x
time = 0

[Command]
name = "CPU5"
command = U,U,D,D,B,F,B,F,y,y
time = 0

[Command]
name = "CPU6"
command = U,U,D,D,B,F,B,F,z,z
time = 0

[Command]
name = "CPU7"
command = U,U,D,D,B,F,B,F,a,b
time = 0

[Command]
name = "CPU8"
command = U,U,D,D,B,F,B,F,b,c
time = 0

[Command]
name = "CPU9"
command = U,U,D,D,B,F,B,F,a,c
time = 0

[Command]
name = "CPU10"
command = U,U,D,D,B,F,B,F,x,y
time = 0

[Command]
name = "CPU11"
command = U,U,D,D,B,F,B,F,y,z
time = 0

[Command]
name = "CPU12"
command = U,U,D,D,B,F,B,F,x,z
time = 0

[Command]
name = "CPU13"
command = U,U,D,D,B,F,B,F,a,x
time = 0

[Command]
name = "CPU14"
command = U,U,D,D,B,F,B,F,a,y
time = 0

[Command]
name = "CPU15"
command = U,U,D,D,B,F,B,F,a,z
time = 0

[Command]
name = "CPU16"
command = U,U,D,D,B,F,B,F,b,x
time = 0

[Command]
name = "CPU17"
command = U,U,D,D,B,F,B,F,b,y
time = 0

[Command]
name = "CPU18"
command = U,U,D,D,B,F,B,F,b,z
time = 0

[Command]
name = "CPU19"
command = U,U,D,D,B,F,B,F,c,x
time = 0

[Command]
name = "CPU20"
command = U,U,D,D,B,F,B,F,c,y
time = 0

[Command]
name = "CPU21"
command = U,U,D,D,B,F,B,F,c,z
time = 0

[Command]
name = "CPU22"
command = U,U,D,D,B,F,B,F,x,a
time = 0

[Command]
name = "CPU23"
command = U,U,D,D,B,F,B,F,x,b
time = 0

[Command]
name = "CPU24"
command = U,U,D,D,B,F,B,F,x,c
time = 0

[Command]
name = "CPU25"
command = U,U,D,D,B,F,B,F,y,a
time = 0

[Command]
name = "CPU26"
command = U,U,D,D,B,F,B,F,y,b
time = 0

[Command]
name = "CPU27"
command = U,U,D,D,B,F,B,F,y,c
time = 0

[Command]
name = "CPU28"
command = U,U,D,D,B,F,B,F,z,a
time = 0

[Command]
name = "CPU29"
command = U,U,D,D,B,F,B,F,z,b
time = 0

[Command]
name = "CPU30"
command = U,U,D,D,B,F,B,F,z,c
time = 0

[Command]
name = "CPU31"
command = U,U,D,D,B,F,B,F,s,s,s
time = 0


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.

;-| Special Motions |------------------------------------------------------
[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_xy"
command = ~F, D, DF, x+y

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_xy"
command = ~D, DF, F, x+y

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_xy"
command = ~D, DB, B, x+y

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

[Command]
name = "xz"
command = x+z
time = 1

[Command]
name = "yz"
command = y+z
time = 1

[Command]
name = "xyz"
command = x+y+z
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "up_b"
command = /$U,b

[Command]
name = "up_c"
command = /$U,c

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

[Command]
name = "F"
command = F
time = 1

[Command]
name = "B"
command = B
time = 1

[Command]
name = "U"
command = U
time = 1

[Command]
name = "D"
command = D
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holdstart"
command = /s
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]
;===========================================================================
;---------------------------------------------------------------------------

;;;;;;;;;;;;
;; AI SET ;;
;;;;;;;;;;;;
[State -1]
type = VarSet
triggerall = var(59) = 0
triggerall = roundstate = 2
trigger1 = command = "CPU0"
trigger2 = command = "CPU1"
trigger3 = command = "CPU2"
trigger4 = command = "CPU3"
trigger5 = command = "CPU4"
trigger6 = command = "CPU5"
trigger7 = command = "CPU6"
trigger8 = command = "CPU7"
v = 59
value = 1

[State -1]
type = VarSet
triggerall = var(59) = 0
triggerall = roundstate = 2
trigger1 = command = "CPU8"
trigger2 = command = "CPU9"
trigger3 = command = "CPU10"
trigger4 = command = "CPU11"
trigger5 = command = "CPU12"
trigger6 = command = "CPU13"
trigger7 = command = "CPU14"
trigger8 = command = "CPU15"
v = 59
value = 1

[State -1]
type = VarSet
triggerall = var(59) = 0
triggerall = roundstate = 2
trigger1 = command = "CPU16"
trigger2 = command = "CPU17"
trigger3 = command = "CPU18"
trigger4 = command = "CPU19"
trigger5 = command = "CPU20"
trigger6 = command = "CPU21"
trigger7 = command = "CPU22"
trigger8 = command = "CPU23"
v = 59
value = 1

[State -1]
type = VarSet
triggerall = var(59) = 0
triggerall = roundstate = 2
trigger1 = command = "CPU24"
trigger2 = command = "CPU25"
trigger3 = command = "CPU26"
trigger4 = command = "CPU27"
trigger5 = command = "CPU28"
trigger6 = command = "CPU29"
trigger7 = command = "CPU30"
trigger8 = command = "CPU31"
v = 59
value = 1

;Turn
;_bV
[State -1, Turn]
type = Turn
triggerall = ctrl
trigger1 = command = "holdback"
trigger1 = command != "holdfwd"

;Jump Up
[State -1, Jump]
type = ChangeState
trigger1 = ctrl
trigger1 = StateType = S
trigger1 = Command = "a"
value = 40

;;;;;;;;;;;;;;;;;
;; REN ATTACKS ;;
;;;;;;;;;;;;;;;;;
;Ren Swatter Straight (Ground)
[State -1, SwatterGround]
type = ChangeState
triggerall = var(0) = 1
triggerall = Statetype = S || StateType = C
triggerall = ctrl
trigger1 = command = "b"
value = 6000
ctrl = 0

;Ren Swatter Straight (Air)
[State -1, SwatterAir]
type = ChangeState
triggerall = var(0) = 1
triggerall = Statetype = A
triggerall = ctrl
trigger1 = command = "b"
value = 6001
ctrl = 0

;Ren Summon Powdered Toast Man
[State -1, SwatterAir]
type = ChangeState
triggerall = var(0) = 1
triggerall = Statetype = S
triggerall = ctrl
triggerall = Power >= 500
triggerall = NumHelper(6003) = 0
trigger1 = command = "c"
value = 6002
ctrl = 0

;;;;;;;;;;;;;;;;;;;;
;; STIMPY ATTACKS ;;
;;;;;;;;;;;;;;;;;;;;
;Stimpy Towel (Ground)
[State -1, TowelGround]
type = ChangeState
triggerall = var(0) = 2
triggerall = Statetype = S || StateType = C
triggerall = ctrl
trigger1 = command = "b"
value = 6007
ctrl = 0

;Stimpy Towel (Air)
[State -1, TowelAir]
type = ChangeState
triggerall = var(0) = 2
triggerall = Statetype = A
triggerall = ctrl
trigger1 = command = "b"
value = 6008
ctrl = 0

;Stimpy Litter Throw (Ground)
[State -1, LitterGround]
type = ChangeState
triggerall = var(0) = 2
triggerall = Statetype = S || StateType = C
triggerall = ctrl
triggerall = Power >= 300
trigger1 = command = "c"
value = 6009
ctrl = 0

;Stimpy Litter Throw (Air)
[State -1, LitterGround]
type = ChangeState
triggerall = var(0) = 2
triggerall = Statetype = A
triggerall = ctrl
triggerall = Power >= 300
trigger1 = command = "c"
value = 6010
ctrl = 0

;;;;;;;;;;;;;;;;;;;;
;; ARNOLD ATTACKS ;;
;;;;;;;;;;;;;;;;;;;;
;Gum (Ground)
[State -1, GumGround]
type = ChangeState
triggerall = var(0) = 3
triggerall = Statetype = S
triggerall = ctrl
triggerall = NumHelper(6014) = 0
triggerall = NumHelper(6015) = 0
trigger1 = Command = "b" && Power >= 100
trigger2 = Command = "c" && Power >= 200
value = 6014
ctrl = 0

;Gum (Crouch)
[State -1, GumCrouch]
type = ChangeState
triggerall = var(0) = 3
triggerall = Statetype = C
triggerall = ctrl
triggerall = NumHelper(6014) = 0
triggerall = NumHelper(6015) = 0
trigger1 = Command = "b" && Power >= 100
trigger2 = Command = "c" && Power >= 200
value = 6015
ctrl = 0

;Gum (Air)
[State -1, GumAir]
type = ChangeState
triggerall = var(0) = 3
triggerall = Statetype = A
triggerall = ctrl
triggerall = NumHelper(6014) = 0
triggerall = NumHelper(6015) = 0
trigger1 = Command = "b" && Power >= 100
trigger2 = Command = "c" && Power >= 200
value = 6016
ctrl = 0

;;;;;;;;;;;;;;;;;;;;
;; GERALD ATTACKS ;;
;;;;;;;;;;;;;;;;;;;;
;Ball (Ground)
[State -1, BallGround]
type = ChangeState
triggerall = var(0) = 4
triggerall = Statetype = S
triggerall = ctrl
triggerall = NumHelper(6026) < 1
trigger1 = Command = "b"
value = 6023
ctrl = 0

;Ball (Crouch)
[State -1, BallCrouch]
type = ChangeState
triggerall = var(0) = 4
triggerall = Statetype = C
triggerall = ctrl
triggerall = NumHelper(6026) < 1
trigger1 = Command = "b"
value = 6024
ctrl = 0

;Ball (Air)
[State -1, BallAir]
type = ChangeState
triggerall = var(0) = 4
triggerall = Statetype = A
triggerall = ctrl
triggerall = NumHelper(6026) < 1
trigger1 = Command = "b"
value = 6025
ctrl = 0

;Shoulder Charge
[State -1, BallGround]
type = ChangeState
triggerall = var(0) = 4
triggerall = Statetype = S
triggerall = ctrl
trigger1 = Command = "c" && Power >= 150
value = 6027
ctrl = 0

;;;;;;;;;;;;;;;;;;;;;
;; GRANDPA ATTACKS ;;
;;;;;;;;;;;;;;;;;;;;;
;Teeth (Ground)
[State -1, TeethGround]
type = ChangeState
triggerall = var(0) = 5
triggerall = Statetype = S
triggerall = ctrl
triggerall = NumHelper(6033) = 0
triggerall = NumHelper(6034) = 0
triggerall = NumHelper(6035) = 0
trigger1 = Command = "b" && Power >= 100
trigger2 = Command = "c" && Power >= 200
value = 6033
ctrl = 0

;Teeth (Crouch)
[State -1, TeethCrouch]
type = ChangeState
triggerall = var(0) = 5
triggerall = Statetype = C
triggerall = ctrl
triggerall = NumHelper(6033) = 0
triggerall = NumHelper(6034) = 0
triggerall = NumHelper(6035) = 0
trigger1 = Command = "b" && Power >= 100
trigger2 = Command = "c" && Power >= 200
value = 6034
ctrl = 0

;Teeth (Air)
[State -1, TeethAir]
type = ChangeState
triggerall = var(0) = 5
triggerall = Statetype = A
triggerall = ctrl
triggerall = NumHelper(6033) = 0
triggerall = NumHelper(6034) = 0
triggerall = NumHelper(6035) = 0
trigger1 = Command = "b" && Power >= 100
trigger2 = Command = "c" && Power >= 200
value = 6035
ctrl = 0

;;;;;;;;;;;;;;;;;;;;;
;; GRANDMA ATTACKS ;;
;;;;;;;;;;;;;;;;;;;;;
;TP (Ground)
[State -1, TPGround]
type = ChangeState
triggerall = var(0) = 6
triggerall = Statetype = S
triggerall = ctrl
triggerall = NumProjID(6044) = 0
trigger1 = Command = "b"
value = 6044
ctrl = 0

;TP (Crouch)
[State -1, TPCrouch]
type = ChangeState
triggerall = var(0) = 6
triggerall = Statetype = C
triggerall = ctrl
triggerall = NumProjID(6044) = 0
trigger1 = Command = "b"
value = 6045
ctrl = 0

;TP (Air)
[State -1, TPAir]
type = ChangeState
triggerall = var(0) = 6
triggerall = Statetype = A
triggerall = ctrl
triggerall = NumProjID(6044) = 0
trigger1 = Command = "b"
value = 6046
ctrl = 0

;Special attack
[State -1, Special]
type = ChangeState
triggerall = var(0) = 6
triggerall = Statetype = S
triggerall = ctrl
trigger1 = Command = "c" && Power >= 500
value = 6047
ctrl = 0

;;;;;;;;;;;;;;;;;;;
;; HELGA ATTACKS ;;
;;;;;;;;;;;;;;;;;;;
;Donut (Ground)
[State -1, DonutGround]
type = ChangeState
triggerall = var(0) = 7
triggerall = Statetype = S
triggerall = ctrl
trigger1 = Command = "b"
value = 6055
ctrl = 0

;Donut (Crouch)
[State -1, DonutCrouch]
type = ChangeState
triggerall = var(0) = 7
triggerall = Statetype = C
triggerall = ctrl
trigger1 = Command = "b"
value = 6056
ctrl = 0

;Donut (Air)
[State -1, DonutAir]
type = ChangeState
triggerall = var(0) = 7
triggerall = Statetype = A
triggerall = ctrl
trigger1 = Command = "b"
value = 6057
ctrl = 0

;Special attack
[State -1, Special]
type = ChangeState
triggerall = var(0) = 7
triggerall = Statetype = S
triggerall = ctrl
trigger1 = Command = "c" && Power >= 300
value = 6058
ctrl = 0

;;;;;;;;;;;;;;;;;;;
;; CLEFT ATTACKS ;;
;;;;;;;;;;;;;;;;;;;
;Rocket (Ground)
[State -1, RocketGround]
type = ChangeState
triggerall = var(0) = 8
triggerall = Statetype = S
triggerall = ctrl
triggerall = NumProjID(6068) = 0
trigger1 = Command = "b"
value = 6068
ctrl = 0

;Rocket (Crouch)
[State -1, RocketCrouch]
type = ChangeState
triggerall = var(0) = 8
triggerall = Statetype = C
triggerall = ctrl
triggerall = NumProjID(6068) = 0
trigger1 = Command = "b"
value = 6069
ctrl = 0

;Rocket (Air)
[State -1, RocketAir]
type = ChangeState
triggerall = var(0) = 8
triggerall = Statetype = A
triggerall = ctrl
triggerall = NumProjID(6068) = 0
trigger1 = Command = "b"
value = 6070
ctrl = 0

;Special Attack
[State -1, SpecialAttack]
type = ChangeState
triggerall = var(0) = 8
triggerall = Statetype = S
triggerall = ctrl
trigger1 = Command = "c" && Power >= 100
value = 6071
ctrl = 0

;;;;;;;;;;;;;;;;;;;
;; COSMO ATTACKS ;;
;;;;;;;;;;;;;;;;;;;
;Safe
[State -1, Safe]
type = ChangeState
triggerall = var(0) = 9
triggerall = Statetype = S
triggerall = ctrl
triggerall = NumProj = 0
trigger1 = Command = "b" && Power >= 100
trigger1 = StateNo != 6077
value = 6076
ctrl = 0

;Dragon
[State -1, Dragon]
type = ChangeState
triggerall = var(0) = 9
triggerall = Statetype = S
triggerall = ctrl
trigger1 = Command = "c" && Power >= 200
trigger1 = StateNo != 6077
value = 6077
ctrl = 0

;;;;;;;;;;;;;;;;;;;
;; WANDA ATTACKS ;;
;;;;;;;;;;;;;;;;;;;
;Beam
[State -1, Beam]
type = ChangeState
triggerall = var(0) = 10
triggerall = Statetype = S
triggerall = ctrl
triggerall = NumProjID(6083) = 0
trigger1 = Command = "b" && Power >= 100
value = 6083
ctrl = 0

;Beam
[State -1, Beam]
type = ChangeState
triggerall = var(0) = 10
triggerall = Statetype = S
triggerall = ctrl
triggerall = NumProjID(6084) = 0
trigger1 = Command = "c" && Power >= 300
value = 6084
ctrl = 0

;;;;;;;;;;;;;;;;;;;;
;; JORGEN ATTACKS ;;
;;;;;;;;;;;;;;;;;;;;
;Charge
[State -1, Charge]
type = ChangeState
triggerall = var(0) = 11
triggerall = Statetype = S
triggerall = ctrl
trigger1 = Command = "b"
value = 6091
ctrl = 0

;Special
[State -1, Special]
type = ChangeState
triggerall = var(0) = 11
triggerall = Statetype = S
triggerall = ctrl
trigger1 = Command = "c" && Power >= 200
value = 6092
ctrl = 0

;;;;;;;;;;;;;;;;;;;;;;;;;
;; COUNTRY BOY ATTACKS ;;
;;;;;;;;;;;;;;;;;;;;;;;;;
;Bomb
[State -1, Bomb]
type = ChangeState
triggerall = var(0) = 12
triggerall = Statetype = S
triggerall = ctrl
triggerall = NumProjID(6098) = 0
trigger1 = Command = "b"
value = 6098
ctrl = 0

;GroundPound
[State -1, GroundPound]
type = ChangeState
triggerall = var(0) = 12
triggerall = Statetype = A
triggerall = ctrl
triggerall = Vel Y > 0
triggerall = Pos Y >= -5
triggerall = StateNo != 6099
trigger1 = Command = "holdc" && Power >= 250
value = 6099
ctrl = 0

;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; BRONZE KNEECAP ATTACKS ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;Knee Punch
[State -1, Punch]
type = ChangeState
triggerall = var(0) = 13
triggerall = Statetype = C
triggerall = ctrl
trigger1 = Command = "b"
value = 6105
ctrl = 0

;Missile
[State -1, Missile]
type = ChangeState
triggerall = var(0) = 13
triggerall = Statetype = C
triggerall = ctrl
triggerall = NumProjID(6106) = 0
trigger1 = Command = "c" && Power >= 150
value = 6106
ctrl = 0

;;;;;;;;;;;;;;;;;;;
;; TOMMY ATTACKS ;;
;;;;;;;;;;;;;;;;;;;
;Melee (Ground)
[State -1, MeleeGround]
type = ChangeState
triggerall = var(0) = 14
triggerall = StateType = S || Statetype = C
triggerall = ctrl
trigger1 = Command = "b"
value = 6112
ctrl = 0

;Melee (Air)
[State -1, MeleeAir]
type = ChangeState
triggerall = var(0) = 14
triggerall = StateType = A
triggerall = ctrl
trigger1 = Command = "b"
value = 6113
ctrl = 0

;Special (Ground)
[State -1, SpecialGround]
type = ChangeState
triggerall = var(0) = 14
triggerall = StateType = S || Statetype = C
triggerall = ctrl
triggerall = NumProjID(6114) < 2
trigger1 = Command = "c" && Power >= 100
value = 6114
ctrl = 0

;Special (Air)
[State -1, SpecialAir]
type = ChangeState
triggerall = var(0) = 14
triggerall = StateType = A
triggerall = ctrl
triggerall = NumProjID(6114) < 2
trigger1 = Command = "c" && Power >= 100
value = 6115
ctrl = 0

;;;;;;;;;;;;;;;;;;;;;
;; CHUCKIE ATTACKS ;;
;;;;;;;;;;;;;;;;;;;;;
;Melee (Ground)
[State -1, MeleeGround]
type = ChangeState
triggerall = var(0) = 15
triggerall = StateType = S || Statetype = C
triggerall = ctrl
trigger1 = Command = "b"
value = 6121
ctrl = 0

;Melee (Air)
[State -1, MeleeAir]
type = ChangeState
triggerall = var(0) = 15
triggerall = StateType = A
triggerall = ctrl
trigger1 = Command = "b"
value = 6122
ctrl = 0

;Special (Ground)
[State -1, SpecialGround]
type = ChangeState
triggerall = var(0) = 15
triggerall = StateType = S || Statetype = C
triggerall = ctrl
triggerall = NumProjID(6123) = 0
trigger1 = Command = "c" && Power >= 100
value = 6123
ctrl = 0

;Special (Air)
[State -1, SpecialAir]
type = ChangeState
triggerall = var(0) = 15
triggerall = StateType = A
triggerall = ctrl
triggerall = NumProjID(6123) = 0
trigger1 = Command = "c" && Power >= 100
value = 6124
ctrl = 0

;;;;;;;;;;;;;;;;;;
;; PHIL ATTACKS ;;
;;;;;;;;;;;;;;;;;;
;Melee (Ground)
[State -1, MeleeGround]
type = ChangeState
triggerall = var(0) = 16
triggerall = StateType = S || Statetype = C
triggerall = ctrl
trigger1 = Command = "b"
value = 6130
ctrl = 0

;Melee (Air)
[State -1, MeleeAir]
type = ChangeState
triggerall = var(0) = 16
triggerall = StateType = A
triggerall = ctrl
trigger1 = Command = "b"
value = 6131
ctrl = 0

;Special (Ground)
[State -1, SpecialGround]
type = ChangeState
triggerall = var(0) = 16
triggerall = StateType = S || Statetype = C
triggerall = ctrl
triggerall = NumProjID(6132) = 0
trigger1 = Command = "c" && Power >= 100
value = 6132
ctrl = 0

;Special (Air)
[State -1, SpecialAir]
type = ChangeState
triggerall = var(0) = 16
triggerall = StateType = A
triggerall = ctrl
triggerall = NumProjID(6132) = 0
trigger1 = Command = "c" && Power >= 100
value = 6133
ctrl = 0

;;;;;;;;;;;;;;;;;
;; LIL ATTACKS ;;
;;;;;;;;;;;;;;;;;
;Melee (Ground)
[State -1, MeleeGround]
type = ChangeState
triggerall = var(0) = 17
triggerall = StateType = S || Statetype = C
triggerall = ctrl
trigger1 = Command = "b"
value = 6139
ctrl = 0

;Melee (Air)
[State -1, MeleeAir]
type = ChangeState
triggerall = var(0) = 17
triggerall = StateType = A
triggerall = ctrl
trigger1 = Command = "b"
value = 6140
ctrl = 0

;Special (Ground)
[State -1, SpecialGround]
type = ChangeState
triggerall = var(0) = 17
triggerall = StateType = S || Statetype = C
triggerall = ctrl
triggerall = NumProjID(6141) = 0
trigger1 = Command = "c" && Power >= 100
value = 6141
ctrl = 0

;Special (Air)
[State -1, SpecialAir]
type = ChangeState
triggerall = var(0) = 17
triggerall = StateType = A
triggerall = ctrl
triggerall = NumProjID(6141) = 0
trigger1 = Command = "c" && Power >= 100
value = 6142
ctrl = 0

;;;;;;;;;;;;;;;;;;
;; KIMI ATTACKS ;;
;;;;;;;;;;;;;;;;;;
;Melee (Ground)
[State -1, MeleeGround]
type = ChangeState
triggerall = var(0) = 18
triggerall = StateType = S || Statetype = C
triggerall = ctrl
trigger1 = Command = "b"
value = 6148
ctrl = 0

;Melee (Air)
[State -1, MeleeAir]
type = ChangeState
triggerall = var(0) = 18
triggerall = StateType = A
triggerall = ctrl
trigger1 = Command = "b"
value = 6149
ctrl = 0

;Special (Ground)
[State -1, SpecialGround]
type = ChangeState
triggerall = var(0) = 18
triggerall = StateType = S || Statetype = C
triggerall = ctrl
triggerall = NumProjID(6150) = 0
trigger1 = Command = "c" && Power >= 100
value = 6150
ctrl = 0

;Special (Air)
[State -1, SpecialAir]
type = ChangeState
triggerall = var(0) = 18
triggerall = StateType = A
triggerall = ctrl
triggerall = NumProjID(6150) = 0
trigger1 = Command = "c" && Power >= 100
value = 6151
ctrl = 0

;;;;;;;;;;;;;;;;;
;; DIL ATTACKS ;;
;;;;;;;;;;;;;;;;;
;Melee (Ground)
[State -1, MeleeGround]
type = ChangeState
triggerall = var(0) = 19
triggerall = StateType = S || Statetype = C
triggerall = ctrl
trigger1 = Command = "b"
value = 6157
ctrl = 0

;Melee (Air)
[State -1, MeleeAir]
type = ChangeState
triggerall = var(0) = 19
triggerall = StateType = A
triggerall = ctrl
trigger1 = Command = "b"
value = 6158
ctrl = 0

;Special (Ground)
[State -1, SpecialGround]
type = ChangeState
triggerall = var(0) = 19
triggerall = StateType = S || Statetype = C
triggerall = ctrl
trigger1 = Command = "c" && Power >= 50
value = 6159
ctrl = 0

;Special (Air)
[State -1, SpecialAir]
type = ChangeState
triggerall = var(0) = 19
triggerall = StateType = A
triggerall = ctrl
trigger1 = Command = "c" && Power >= 50
value = 6160
ctrl = 0

;;;;;;;;;;;;;;;;;;;;;;
;; ANGELICA ATTACKS ;;
;;;;;;;;;;;;;;;;;;;;;;
;Melee (Ground)
[State -1, MeleeGround]
type = ChangeState
triggerall = var(0) = 20
triggerall = StateType = S
triggerall = ctrl
trigger1 = Command = "b"
value = 6166
ctrl = 0

;Melee (Crouch)
[State -1, MeleeCrouch]
type = ChangeState
triggerall = var(0) = 20
triggerall = StateType = C
triggerall = ctrl
trigger1 = Command = "b"
value = 6167
ctrl = 0

;Melee (Air)
[State -1, MeleeAir]
type = ChangeState
triggerall = var(0) = 20
triggerall = StateType = A
triggerall = ctrl
trigger1 = Command = "b"
value = 6168
ctrl = 0

;Special
[State -1, Special]
type = ChangeState
triggerall = var(0) = 20
triggerall = StateType = S
triggerall = ctrl
trigger1 = Command = "c" && Power >= 300
value = 6169
ctrl = 0

;;;;;;;;;;;;;;;;;;;
;; JIMMY ATTACKS ;;
;;;;;;;;;;;;;;;;;;;
;Beam (Ground)
[State -1, BeamGround]
type = ChangeState
triggerall = var(0) = 21
triggerall = StateType = S
triggerall = ctrl
triggerall = NumProjID(6175) = 0
trigger1 = Command = "b" && Power >= 50
value = 6175
ctrl = 0

;Beam (Crouch)
[State -1, BeamCrouch]
type = ChangeState
triggerall = var(0) = 21
triggerall = StateType = C
triggerall = ctrl
triggerall = NumProjID(6175) = 0
trigger1 = Command = "b" && Power >= 50
value = 6176
ctrl = 0

;Beam (Air)
[State -1, BeamGround]
type = ChangeState
triggerall = var(0) = 21
triggerall = StateType = A
triggerall = ctrl
triggerall = NumProjID(6175) = 0
trigger1 = Command = "b" && Power >= 50
value = 6177
ctrl = 0

;Freeze Ray (Ground)
[State -1, FRayGround]
type = ChangeState
triggerall = var(0) = 21
triggerall = StateType = S
triggerall = ctrl
triggerall = NumProjID(6178) = 0
trigger1 = Command = "c" && Power >= 100
value = 6178
ctrl = 0

;Freeze Ray (Crouch)
[State -1, FRayCrouch]
type = ChangeState
triggerall = var(0) = 21
triggerall = StateType = C
triggerall = ctrl
triggerall = NumProjID(6178) = 0
trigger1 = Command = "c" && Power >= 100
value = 6179
ctrl = 0

;Freeze Ray (Air)
[State -1, FRayAir]
type = ChangeState
triggerall = var(0) = 21
triggerall = StateType = A
triggerall = ctrl
triggerall = NumProjID(6178) = 0
trigger1 = Command = "c" && Power >= 100
value = 6180
ctrl = 0

;;;;;;;;;;;;;;;;;;;;;
;; GODDARD ATTACKS ;;
;;;;;;;;;;;;;;;;;;;;;
;Beam (Ground)
[State -1, BeamGround]
type = ChangeState
triggerall = var(0) = 22
triggerall = StateType = S
triggerall = ctrl
triggerall = NumProjID(6186) = 0
trigger1 = Command = "b" && Power >= 50
value = 6186
ctrl = 0

;Beam (Crouch)
[State -1, BeamCrouch]
type = ChangeState
triggerall = var(0) = 22
triggerall = StateType = C
triggerall = ctrl
triggerall = NumProjID(6186) = 0
trigger1 = Command = "b" && Power >= 50
value = 6187
ctrl = 0

;Beam (Air)
[State -1, BeamAir]
type = ChangeState
triggerall = var(0) = 22
triggerall = StateType = A
triggerall = ctrl
triggerall = NumProjID(6186) = 0
trigger1 = Command = "b" && Power >= 50
value = 6188
ctrl = 0

;Heat Ray (Ground)
[State -1, HeatRayGround]
type = ChangeState
triggerall = var(0) = 22
triggerall = StateType = S
triggerall = ctrl
triggerall = NumProjID(6189) = 0
trigger1 = Command = "c" && Power >= 80
value = 6189
ctrl = 0

;Heat Ray (Crouch)
[State -1, HeatRayCrouch]
type = ChangeState
triggerall = var(0) = 22
triggerall = StateType = C
triggerall = ctrl
triggerall = NumProjID(6189) = 0
trigger1 = Command = "c" && Power >= 80
value = 6190
ctrl = 0

;Heat Ray (Air)
[State -1, HeatRayAir]
type = ChangeState
triggerall = var(0) = 22
triggerall = StateType = A
triggerall = ctrl
triggerall = NumProjID(6189) = 0
trigger1 = Command = "c" && Power >= 80
value = 6191
ctrl = 0

;Cancel Jump
[State -1, JumpCancel]
type = ChangeState
value = 0
trigger1 = command = "holdup"
trigger1 = statetype != A
trigger1 = ctrl = 1

;Go to menu state.
[State -1, MenuSound]
type = ChangeState
triggerall = Statetype = S || Statetype = C
triggerall = ctrl
trigger1 = command = "start"
value = 200
ctrl = 0